/*
	Replication code for Autor (JEP 2015)
	Description: Plots occupation employment and wage growth by percentile of 1980 wages.
	
	Author: Brendan Price
	Updated: July 15, 2015
*/

version 12.1
set more off
set varabbrev off
capture restore, not

/* Rank occupations based on their 1980 mean log wage */

use "../dta/census-acs/clean/1980.dta", clear

* Restrict to workers with positive labor supply and a valid wage
keep if lswt > 0 & lswt < .
keep if wage > 0 & wage < .

* Further restrict to workers making at least 25% of the prevailing federal minimum wage.
* The minimum wage prevailing in 1979 was $2.90, which in 2011 dollars equals $7.74 (using the PCE)
keep if wage > .25 * 7.74

* Compute the hours-weighted mean log wage in each occupation
gen lwage = log(wage)
collapse (count) num_obs = lwage (mean) lwage [aw = lswt], by(occ1990dd)
sort lwage

* Make sure there's at least 50 observations for each occupation
assert num_obs >= 50
drop num_obs

* Rank occupations in increasing order of mean log wage
sort lwage
gen occ_rank = _n
keep occ1990dd occ_rank
tempfile ranks
saveold "`ranks'.dta", replace

/*
	Assign occupations to percentiles based on their wage ranking.
	For this purpose, I use a 1980 "employment sample" rather than a "wage sample".
	I split occupations as needed if they straddle multiple percentiles.
*/

use "../dta/census-acs/clean/1980.dta", clear
collapse (sum) lswt, by(occ1990dd)
drop if occ1990dd == .
merge m:1 occ1990dd using "`ranks'.dta", assert(3) nogenerate

* Determine the interval taken up by each occupation
egen totlswt = total(lswt)
sort occ_rank
gen sumlswt = sum(lswt)
gen perc = 100 * (sumlswt/totlswt)
keep occ1990dd perc
sort perc
gen perc_start = perc[_n - 1]
replace perc_start = 0 in 1
rename perc perc_end
order occ1990dd perc_start perc_end

* Determine the minimum and maximum percentiles straddled by each occupation
gen min_perc = max(1, ceil(perc_start))
gen max_perc = max(1, ceil(perc_end))

* Merge in 1-digit occupation codes
merge m:1 occ1990dd using "../cw/occ1990dd_occ10/occ1990dd_occ10.dta", assert(3) nogenerate keepusing(occ10)

label drop occ10_lbl

#delimit ;
label define occ10_lbl
	11 "Managers"
	12 "Professionals"
	13 "Technicians"
	21 "Sales"
	22 "Office/Admin"
	23 "Production"
	31 "Operators/Laborers"
	32 "Protective Service"
	33 "Food/Cleaning Service"
	34 "Personal Care"
	40 "Agriculture";
#delimit cr

label values occ10 occ10_lbl

* Determine the number of percentiles to which an occupation contributes
gen num_percs = max_perc - min_perc + 1

* One observation per occupation x percentile
expand num_percs
bysort occ1990dd: gen n = _n
gen perc = min_perc + (n - 1)
sort perc_start perc
keep occ1990dd perc_start perc_end perc

* Determine what fraction of the occupation to map into this percentile
gen perc_span = min(perc_end, perc) - max(perc_start, perc - 1)
gen frac = perc_span/(perc_end - perc_start)
keep occ1990dd perc frac
bysort occ1990dd: egen tot_frac = total(frac)
assert abs(tot_frac - 1) < .01
drop tot_frac

* Save as a crosswalk
sort occ1990dd perc
tempfile percentiles
saveold "`percentiles'.dta", replace

/* Compute employment, earnings (among FTFY workers), and weeks worked (among FTFY workers) by occupation in each year */

* Employment by occupation
foreach y of numlist 1980 1990 2000 2007 2012 {
	use "../dta/census-acs/clean/`y'.dta", clear
	collapse (sum) lswt, by(year occ1990dd)
	drop if occ1990dd == .
	tempfile emp`y'
	saveold "`emp`y''.dta", replace
}

use "`emp1980'.dta", clear
append using "`emp1990'.dta"
append using "`emp2000'.dta"
append using "`emp2007'.dta"
append using "`emp2012'.dta"
fillin year occ1990dd
replace lswt = 0 if _fillin == 1
drop _fillin
tempfile emp
saveold "`emp'.dta", replace

* Earnings and weeks worked among FTFY workers
foreach y of numlist 1980 1990 2000 2007 2012 {
	use "../dta/census-acs/clean/`y'.dta", clear

	* Restrict to workers employed full-time and full-year
	keep if wkswork1 >= 48 & uhrswork >= 35
	assert lswt > 0 & lswt < .
	assert occ1990dd != .

	* Sum up earnings and weeks worked across workers
	gen incwt = incwage * perwt
	gen wkswt = wkswork1 * perwt
	collapse (sum) incwt wkswt, by(year occ1990dd)
	tempfile earnings`y'
	saveold "`earnings`y''.dta", replace
}

use "`earnings1980'.dta", clear
append using "`earnings1990'.dta"
append using "`earnings2000'.dta"
append using "`earnings2007'.dta"
append using "`earnings2012'.dta"
fillin year occ1990dd
replace incwt = 0 if _fillin == 1
replace wkswt = 0 if _fillin == 1
drop _fillin
tempfile earnings
saveold "`earnings'.dta", replace

use "`emp'.dta", clear
merge 1:1 year occ1990dd using "`earnings'.dta", assert(3) nogenerate

* Tweak years because Census survey years do not coincide with Census data years
replace year = 1979 if year == 1980
replace year = 1989 if year == 1990
replace year = 1999 if year == 2000

/* Map occupations into percentiles */

joinby occ1990dd using "`percentiles'.dta", _merge(_merge)
assert _merge == 3
drop _merge
replace lswt = lswt * frac
replace incwt = incwt * frac
replace wkswt = wkswt * frac
collapse (sum) lswt incwt wkswt, by(year perc)

/* Compute mean weekly earnings by occupation percentile */

gen wkwage = incwt/wkswt
assert wkwage > 0 & wkwage < .
keep year perc lswt wkwage
reshape wide lswt wkwage, i(perc) j(year)
label var perc "Skill Percentile (Ranked by Occupation's 1979 Mean Log Wage)"
order perc lswt* wkwage*

* Occupation employment shares
foreach y of numlist 1979 1989 1999 2007 2012 {
	egen totlswt`y' = total(lswt`y')
	gen occsh`y' = lswt`y'/totlswt`y'
	drop lswt`y' totlswt`y'
}

tempfile main
saveold "`main'.dta", replace

/* Plot smoothed changes in occupation employment shares and occupation mean weekly wages */

foreach y in "emp" "wage" {
	if "`y'" == "emp" {
		local y_lbl "Employment"
		local ytitle "100 x Change in Employment Share"
		local ystem "dsh"
		local yrange "-.1 .2"
		local ylabel "-.1(.1).2"
	}
	else if "`y'" == "wage" {
		local y_lbl "Wage"
		local ytitle "100 x Log Change in Mean FTFY Wage"
		local ystem "dwkwage"
		local yrange "-5 20"
		local ylabel "-5(5)20"
	}

	use "`main'.dta", clear
	
	* Compute smoothed changes in employment/wages by skill percentile
	foreach t in "1979_2012" "1979_1989" "1989_1999" "1999_2007" "2007_2012" {
		local t1 = substr("`t'", 1, 4)
		local t2 = substr("`t'", 6, 4)

		* Changes in employment shares or changes in log wages
		if "`y'" == "emp" {
			gen dy_`t' = 100 * (occsh`t2' - occsh`t1')

		}
		else if "`y'" == "wage" {
			gen dy_`t' = 100 * (log(wkwage`t2') - log(wkwage`t1'))

		}
		
		* Smoothing (using a bandwidth of .75)
		lowess dy_`t' perc, gen(pred_`t') bwidth(.75) nograph
		label var pred_`t' "Smoothed Change over `t1'-`t2'"
	}
	
	* Plot the four series together
	sort perc
	#delimit ;
	twoway (connected pred_1979_1989 perc, msymbol(circle) msize(vsmall) mcolor(navy) clcolor(navy) clstyle(dot))
		(connected pred_1989_1999 perc, msymbol(triangle) msize(vsmall) mcolor(maroon) clcolor(maroon) clstyle(dash))
		(connected pred_1999_2007 perc, msymbol(square) msize(vsmall) mcolor(dkorange) clcolor(dkorange) clstyle(solid))
		(connected pred_2007_2012 perc, msymbol(diamond) msize(vsmall) mcolor(dkgreen) clcolor(dkgreen) clstyle(longdash)),
		title("Smoothed `y_lbl' Changes by Skill Percentile, 1979-2012", size(medsmall))
		xtitle("Skill Percentile (Ranked by Occupation's 1979 Mean Log Wage)", size(medsmall))
		ytitle("`ytitle'", size(medsmall))
		ylabel("`ylabel'", labsize(medsmall))
		yscale(range(`yrange'))
		yline(0)
		legend(rows(1) size(small) symxsize(*.75) label(1 "1979-1989") label(2 "1989-1999") label(3 "1999-2007") label(4 "2007-2012"));
	#delimit cr	

	graph export "../out/occ-percentiles/occ-percentiles-`y'.eps", as(eps) replace
	!epstopdf --outfile="../out/occ-percentiles/occ-percentiles-`y'.pdf" "../out/occ-percentiles/occ-percentiles-`y'.eps"
	rm "../out/occ-percentiles/occ-percentiles-`y'.eps"
	
	* Save the plotting points
	keep perc pred_*
	saveold "../out/occ-percentiles/occ-percentiles-`y'-plotting-points.dta", replace
}



